//-----------------------------------------------------------------------
//	File:		$RCSfile: ShipROM.v,v $
//	Version:	$Revision: 1.0 $
//	Desc:		ROM for dot matrix representation of Ship parts
//	Author:		David Chen
//	Copyright:	Copyright 2006 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Change Log
//-----------------------------------------------------------------------
//	$Log: ShipROM.v,v $
//	Revision 1.0  2006/03/24 12:29:56  Administrator
//	Cleaned up code; Added parameters
//	
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		ShipROM
//	Desc:		Dot matrix representation of ships
//	Params:		see below...
//-----------------------------------------------------------------------
`timescale 1ns / 1ps

//-----------------------------------------------------------------------
//    NOTE: This ShipROM assumes a specific data representation. You are
//          NOT required to use this module and, if you do, you are free
//          to modify it however you see fit.
//-----------------------------------------------------------------------

module ShipROM(Data, DotMatrix);
	input [7:0]		Data;

	//-----------------------------------------------------------------
	//    Ship representation:
	//
	//    +--------------------+---------------+-----+
	//    |     Ship Index     |     Type*     | Hit |
	//    +--------------------+---------------+-----+
	//
	//    * Where type is one of:
	//       blank, left tail, right tail, up tail, down tail,
	//       horizontal tail, vertical tail, or unknown
	//-----------------------------------------------------------------

	output [63:0]	DotMatrix;
	wire   [63:0]  DotMatrix;
	reg [63:0]		DotMatrixRaw;
	
	//-----------------------------------------------------------------
	//    Dot matrix representation of ship parts
	//-----------------------------------------------------------------
	always @( * ) begin
		case (Data[3:1])
		// No ship
		3'b000:
		DotMatrixRaw = {8'b00000000,
							 8'b00000000,
							 8'b00000000,
							 8'b00000000,
							 8'b00000000,
							 8'b00000000,
							 8'b00000000,
							 8'b00000000};

		// Left tail
		3'b001:
		DotMatrixRaw = {8'b00000000,
							 8'b00000000,
							 8'b00011111,
							 8'b00111111,
							 8'b01111111,
							 8'b00111111,
							 8'b00011111,
							 8'b00000000};

		// Horizontal section
		3'b010:
		DotMatrixRaw = {8'b00000000,
							 8'b00000000,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b00000000};

		// Right tail
		3'b011:
		DotMatrixRaw = {8'b00000000,
							 8'b00000000,
							 8'b11111100,
							 8'b11111110,
							 8'b11111111,
							 8'b11111110,
							 8'b11111100,
							 8'b00000000};

		// Up tail
		3'b100:
		DotMatrixRaw = {8'b00000000,
							 8'b00001000,
							 8'b00011100,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110};

		// Vertical section
		3'b101:
		DotMatrixRaw = {8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110};

		// Down tail
		3'b110:
		DotMatrixRaw = {8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00111110,
							 8'b00011100,
							 8'b00001000,
							 8'b00000000};

		// Unknown but part of ship
		3'b111:
		DotMatrixRaw = {8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111,
							 8'b11111111};

		default:
		DotMatrixRaw = {8'b000000000,
							 8'b000000000,
							 8'b000000000,
							 8'b000000000,
							 8'b000000000,
							 8'b000000000,
							 8'b000000000,
							 8'b000000000};
		endcase
	end
	
	assign DotMatrix = {DotMatrixRaw[0],DotMatrixRaw[1],DotMatrixRaw[2],DotMatrixRaw[3],DotMatrixRaw[4],DotMatrixRaw[5],DotMatrixRaw[6],DotMatrixRaw[7],
				DotMatrixRaw[8],DotMatrixRaw[9],DotMatrixRaw[10],DotMatrixRaw[11],DotMatrixRaw[12],DotMatrixRaw[13],DotMatrixRaw[14],DotMatrixRaw[15],
				DotMatrixRaw[16],DotMatrixRaw[17],DotMatrixRaw[18],DotMatrixRaw[19],DotMatrixRaw[20],DotMatrixRaw[21],DotMatrixRaw[22],DotMatrixRaw[23],
				DotMatrixRaw[24],DotMatrixRaw[25],DotMatrixRaw[26],DotMatrixRaw[27],DotMatrixRaw[28],DotMatrixRaw[29],DotMatrixRaw[30],DotMatrixRaw[31],
				DotMatrixRaw[32],DotMatrixRaw[33],DotMatrixRaw[34],DotMatrixRaw[35],DotMatrixRaw[36],DotMatrixRaw[37],DotMatrixRaw[38],DotMatrixRaw[39],
				DotMatrixRaw[40],DotMatrixRaw[41],DotMatrixRaw[42],DotMatrixRaw[43],DotMatrixRaw[44],DotMatrixRaw[45],DotMatrixRaw[46],DotMatrixRaw[47],
				DotMatrixRaw[48],DotMatrixRaw[49],DotMatrixRaw[50],DotMatrixRaw[51],DotMatrixRaw[52],DotMatrixRaw[53],DotMatrixRaw[54],DotMatrixRaw[55],
				DotMatrixRaw[56],DotMatrixRaw[57],DotMatrixRaw[58],DotMatrixRaw[59],DotMatrixRaw[60],DotMatrixRaw[61],DotMatrixRaw[62],DotMatrixRaw[63]	};
endmodule
